body, p, li {
  font-family: Arial,Helvetica,sans-serif;
  color: black;
  font-size:18px;
  text-align:center; /* for IE */
  margin:0 auto; /* for the rest */
}
a {
  color: black;
  text-decoration: underline;
  font-family: Arial,Helvetica,sans-serif;
}
a:hover {
  color: #ff9900;
  text-decoration: underline;
  font-family: Arial,Helvetica,sans-serif;
}
